summaryrefslogtreecommitdiffstats
path: root/qtsharp/src/examples/tutorials/t2.cs
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:44:01 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:44:01 +0000
commit479f5f799523bffbcc83dff581a2299c047c6fff (patch)
tree186aae707ed02aac6c7cab2fb14e97f72aca5e36 /qtsharp/src/examples/tutorials/t2.cs
parentf1dbff6145c98324ff82e34448b7483727e8ace4 (diff)
downloadtdebindings-479f5f799523bffbcc83dff581a2299c047c6fff.tar.gz
tdebindings-479f5f799523bffbcc83dff581a2299c047c6fff.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebindings@1157645 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'qtsharp/src/examples/tutorials/t2.cs')
-rw-r--r--qtsharp/src/examples/tutorials/t2.cs12
1 files changed, 6 insertions, 6 deletions
diff --git a/qtsharp/src/examples/tutorials/t2.cs b/qtsharp/src/examples/tutorials/t2.cs
index 44eb304b..5dbe07d1 100644
--- a/qtsharp/src/examples/tutorials/t2.cs
+++ b/qtsharp/src/examples/tutorials/t2.cs
@@ -9,17 +9,17 @@ public class Example {
public static int Main (String[] args)
{
- QApplication a = new QApplication (args);
+ TQApplication a = new TQApplication (args);
- QPushButton quit = new QPushButton ("Quit", null);
+ TQPushButton quit = new TQPushButton ("Quit", null);
// In C++, the second parameter is 0 (null pointer)
quit.Resize (75, 30);
- quit.SetFont (new QFont ("Times", 18, QFont.Weight.Bold));
- // In C++, QFont::Bold is sufficient
+ quit.SetFont (new TQFont ("Times", 18, TQFont.Weight.Bold));
+ // In C++, TQFont::Bold is sufficient
- QObject.Connect ( quit, QtSupport.SIGNAL ("clicked()"), a, QtSupport.SLOT ("Quit()") );
- // SIGNAL and SLOT are static functions of QtSupport
+ TQObject.Connect ( quit, QtSupport.TQT_SIGNAL ("clicked()"), a, QtSupport.TQT_SLOT ("Quit()") );
+ // TQT_SIGNAL and TQT_SLOT are static functions of QtSupport
a.SetMainWidget (quit);
quit.Show ();